@@ -3,6 +3,8 @@ might want to debug."""
 
 from Products.CMFPlone.MigrationTool import MigrationTool
 
+orig_upgrade = MigrationTool.upgrade
+
 def upgrade(self, REQUEST=None, dry_run=None, swallow_errors=0):
     """Keep portal migrations from swallowing errors."""
-    return MigrationTool.upgrade(self, REQUEST, dry_run, swallow_errors)
+    return orig_upgrade(self, REQUEST, dry_run, swallow_errors)
