@@ -23,21 +23,23 @@ def error(self, msg, *args, **kw):
     """Drop into pdb when logging an error."""
     result = orig_error(self, msg, *args, **kw)
 
+    if not isinstance(msg, basestring):
+        msg = str(msg)
+
     for matcher in ignore_matchers:
         try:
             match = matcher(msg)
         except:
             logger.exception('Matcher %r failed for log message %r' %
                              (matcher, msg))
-        if match:
-            break
-    else:
-        type, value, traceback = sys.exc_info()
-        if traceback is None:
-            set_trace()
         else:
-            # When the logger is invoked inside a try block, do
-            # post_mortem debugging on the error
+            if match:
+                break
+    else:
+        if kw.get('exc_info'):
+            type, value, traceback = sys.exc_info()
             post_mortem(traceback)
+        else:
+            set_trace()
         
     return result
